bug-gnu-emacs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

bug#30812: Perl syntax highlighting regression in fix for #27613? (feecb


From: Clément Pit-Claudel
Subject: bug#30812: Perl syntax highlighting regression in fix for #27613? (feecb66b6fe41c977b8e11b5f2d419c9544f42de)
Date: Tue, 13 Mar 2018 19:14:56 -0400
User-agent: Mozilla/5.0 (X11; Linux x86_64; rv:52.0) Gecko/20100101 Thunderbird/52.6.0

X-Debbugs-CC: jeffersoncarpenter2@gmail.com

Hi all,

I think the following commit was a bit too enthusiastic, as variables like 
@temp are now highlighted in font-lock-type-face.

diff --git a/lisp/progmodes/perl-mode.el b/lisp/progmodes/perl-mode.el
--- a/lisp/progmodes/perl-mode.el
+++ b/lisp/progmodes/perl-mode.el
@@ -181,4 +181,5 @@
      ;;
-     ;; Fontify local and my keywords as types.
-     ("\\<\\(local\\|my\\)\\>" . font-lock-type-face)
+     ;; Fontify declarators and prefixes as types.
+     
("\\<\\(anon\\|argument\\|has\\|local\\|my\\|our\\|state\\|supersede\\)\\>" . 
font-lock-type-face) ; declarators
+     ("\\<\\(let\\|temp\\)\\>" . font-lock-type-face) ; prefixes
      ;;

Am I missing something? (I don't speak Perl, so I noticed this in a regression 
test)

Clément.


Attachment: signature.asc
Description: OpenPGP digital signature


reply via email to

[Prev in Thread] Current Thread [Next in Thread]